#! /bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/mod_jk-update.sh - paramater update script
#
# Copyright (c) 2007-2008 Sebastian Scholze <webmaster(at)schlotze(dot)de
#
# Creation   : 2007-02-28 scholze
# Last update: $Id: mod_jk-update.sh 20776 2009-08-14 15:37:53Z schlotze $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------


#exec 2>/public/mod_jk-update-trace$$.log
#set -x

packages_name=mod_jk


# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib


### ---------------------------------------------------------------------------
### Set the default values for configuration
### ---------------------------------------------------------------------------
JK_LOG_LEVEL='info'
JK_MOUNT_N='3'
JK_MOUNT_1_ACTIVE='no'
JK_MOUNT_1_URL='/jsp-examples/*'
JK_MOUNT_2_ACTIVE='no'
JK_MOUNT_2_URL='/servlets-examples/*'
JK_MOUNT_3_ACTIVE='no'
JK_MOUNT_3_URL='/jsp-examples/*.jsp'
JK_STATUS='no'
JK_TOMCAT_HOST='localhost'
JK_TOMCAT_PORT='8009'
### ---------------------------------------------------------------------------
### read old configuration and rename old variables
### ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${packages_name} ]
    then
        . /etc/config.d/${packages_name}
    fi

}

### ---------------------------------------------------------------------------
### Write config and default files
### ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    (
    #--------------------------------------------------------------------------------
    printgpl -conf "$packages_name" "2007-05-02" "schlotze" "2003-2007 Sebastian Scholze <webmaster@schlotze.de>"
    #--------------------------------------------------------------------------------


    #--------------------------------------------------------------------------------
    printgroup "Basic configuration"
    #--------------------------------------------------------------------------------
    printvar "JK_TOMCAT_HOST" "Host where the tomcat is running (e.g. 'localhost')."
    printvar "JK_TOMCAT_PORT" "Port on which the AJP worker is accesible (e.g. '8009')."
    printvar "JK_LOG_LEVEL" "Log level of jk"

    #--------------------------------------------------------------------------------
    printgroup "Mount configurations"
    #--------------------------------------------------------------------------------
    printvar "JK_MOUNT_N" "number of mounts"
    idx=1
    while [ "${idx}" -le "${JK_MOUNT_N}" ]
    do
        echo
        printvar "JK_MOUNT_${idx}_ACTIVE" "active yes/no"
        printvar "JK_MOUNT_${idx}_URL" "url"
        
    idx=`/usr/bin/expr ${idx} + 1`
    done
    printvar "JK_STATUS" "shall status worker be enabled: yes/no"
    

    #--------------------------------------------------------------------------------
    printend
    #--------------------------------------------------------------------------------

    ) > ${internal_conf_file}
    # Set rights
    chmod 0644 ${internal_conf_file}
    chown root ${internal_conf_file}
}

### -------------------------------------------------------------------------
### Create the check.d file
### -------------------------------------------------------------------------
make_check_file()
{
    printgpl -check "$packages_name" "2007-05-02" "schlotze" "Sebastian Scholze" > /etc/check.d/${packages_name}
cat >> /etc/check.d/${packages_name} << EOF
# Variable          OPT_VARIABLE          VARIABLE_N          VALUE
JK_LOG_LEVEL        -                     -                   JK_LOG_LEVEL
JK_MOUNT_N          -                     -                   NUMERIC
JK_MOUNT_%_ACTIVE   -                     JK_MOUNT_N          YESNO
JK_MOUNT_%_URL      -                     JK_MOUNT_N          JK_MOUNT_PATH
JK_STATUS           -                     -                   YESNO
JK_TOMCAT_HOST      -                     -                   HOSTNAME
JK_TOMCAT_PORT      -                     -                   PORT
EOF

   	# Set rights for check.d file
   	chmod 0644 /etc/check.d/${packages_name}
   	chown root /etc/check.d/${packages_name}

    printgpl -check_exp "$packages_name" "2007-05-02" "schlotze" "Sebastian Scholze" > /etc/check.d/${packages_name}.exp
cat >> /etc/check.d/${packages_name}.exp << EOF
JK_LOG_LEVEL          = '|debug|info|error'  
                      : 'only debug,info or error is allowed'
JK_MOUNT_PATH         = '/((([[:alnum:]]|[-_.]|[\*])+)(/([[:alnum:]]|[-_.]|[\*])+)*?)?'
                      : 'Use path without / of the end'
EOF
    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${packages_name}.exp
    chown root /etc/check.d/${packages_name}.exp
}

### ---------------------------------------------------------------------------
### Main
### ---------------------------------------------------------------------------
# write default config file
make_config_file /etc/default.d/${packages_name}

# update from old version
rename_old_variables

# write new config file
make_config_file /etc/config.d/${packages_name}

# write check.d file
make_check_file

exit 0
### ---------------------------------------------------------------------------
### End
###----------------------------------------------------------------------------
